@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # Copyright, 2017, by Samuel G. D. Williams. <http://www.codeotaku.com>
 # 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -33,6 +35,10 @@ module Console
 			@buffer.last
 		end
 		
+		def include?(pattern)
+			JSON.dump(@buffer).include?(pattern)
+		end
+		
 		def clear
 			@buffer.clear
 		end
