@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # Copyright, 2019, by Samuel G. D. Williams. <http://www.codeotaku.com>
 # 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -27,8 +29,8 @@ module Console
 			def to_h
 			end
 			
-			def as_json
-				to_h
+			def to_json(*arguments)
+				JSON.generate([self.class, to_h], *arguments)
 			end
 			
 			def format(buffer, terminal)
