@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # Copyright, 2017, by Samuel G. D. Williams. <http://www.codeotaku.com>
 # 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,13 +28,14 @@ module Console
 			def self.for(*arguments, **options)
 				# Extract out the command environment:
 				if arguments.first.is_a?(Hash)
-					self.new(*arguments, **options)
+					environment = arguments.shift
+					self.new(environment, arguments, options)
 				else
-					self.new(nil, arguments, **options)
+					self.new(nil, arguments, options)
 				end
 			end
 			
-			def initialize(environment, *arguments, **options)
+			def initialize(environment, arguments, options)
 				@environment = environment
 				@arguments = arguments
 				@options = options
@@ -53,7 +56,11 @@ module Console
 			end
 			
 			def to_h
-				{environment: @environment, arguments: @arguments, options: @options}
+				Hash.new.tap do |hash|
+					hash[:environment] = @environment if @environment&.any?
+					hash[:arguments] = @arguments if @arguments&.any?
+					hash[:options] = @options if @options&.any?
+				end
 			end
 			
 			def format(output, terminal, verbose)
