@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # Copyright, 2017, by Samuel G. D. Williams. <http://www.codeotaku.com>
 # 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,11 +28,12 @@ module Console
 	class Filter
 		def self.[] **levels
 			klass = Class.new(self)
+			min_level, max_level = levels.values.minmax
 			
 			klass.instance_exec do
 				const_set(:LEVELS, levels)
-				const_set(:MINIMUM_LEVEL, levels.values.min)
-				const_set(:MAXIMUM_LEVEL, levels.values.max)
+				const_set(:MINIMUM_LEVEL, min_level)
+				const_set(:MAXIMUM_LEVEL, max_level)
 				
 				levels.each do |name, level|
 					const_set(name.to_s.upcase, level)
@@ -102,7 +105,7 @@ module Console
 		end
 		
 		def all!
-			@level = -1
+			@level = self.class::MINIMUM_LEVEL - 1
 		end
 		
 		# You can enable and disable logging for classes. This function checks if logging for a given subject is enabled.
