@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # Copyright, 2017, by Samuel G. D. Williams. <http://www.codeotaku.com>
 # 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -25,6 +27,7 @@ require_relative 'text'
 require_relative 'xterm'
 
 require 'json'
+require 'fiber'
 
 module Console
 	module Terminal
@@ -54,11 +57,11 @@ module Console
 		end
 		
 		class Logger
-			def initialize(io = $stderr, verbose: nil, start_at: Terminal.start_at!, **options)
+			def initialize(io = $stderr, verbose: nil, start_at: Terminal.start_at!, format: nil, **options)
 				@io = io
 				@start_at = start_at
 				
-				@terminal = Terminal.for(io)
+				@terminal = format.nil? ? Terminal.for(io) : format.new(io)
 				
 				if verbose.nil?
 					@verbose = !@terminal.colors?
@@ -66,7 +69,6 @@ module Console
 					@verbose = verbose
 				end
 				
-				@terminal[:logger_prefix] ||= @terminal.style(nil, nil, nil)
 				@terminal[:logger_suffix] ||= @terminal.style(:white, nil, :faint)
 				@terminal[:subject] ||= @terminal.style(nil, nil, :bold)
 				@terminal[:debug] = @terminal.style(:cyan)
@@ -96,7 +98,7 @@ module Console
 				end
 			end
 			
-			UNKNOWN = 'unknown'
+			UNKNOWN = :unknown
 			
 			def call(subject = nil, *arguments, name: nil, severity: UNKNOWN, **options, &block)
 				prefix = build_prefix(name || severity.to_s)
@@ -136,7 +138,7 @@ module Console
 			def format_argument(argument, output)
 				case argument
 				when Exception
-					Event::Failure.new(argument).format(output, @terminal, @verbose)
+					Event::Failure.for(argument).format(output, @terminal, @verbose)
 				when Event::Generic
 					argument.format(output, @terminal, @verbose)
 				else
@@ -154,11 +156,21 @@ module Console
 				end
 			end
 			
+			def default_suffix(object = nil)
+				buffer = +" #{@terminal[:logger_suffix]}"
+				
+				if object
+					buffer << "[oid=0x#{object.object_id.to_s(16)}] "
+				end
+				
+				buffer << "[ec=0x#{Fiber.current.object_id.to_s(16)}] [pid=#{Process.pid}] [#{::Time.now}]#{@terminal.reset}"
+			end
+			
 			def format_object_subject(severity, prefix, subject, output)
 				prefix_style = @terminal[severity]
 				
 				if @verbose
-					suffix = " #{@terminal[:logger_suffix]}[oid=0x#{subject.object_id.to_s(16)}] [pid=#{Process.pid}] [#{Time.now}]#{@terminal.reset}"
+					suffix = default_suffix(subject)
 				end
 				
 				prefix = "#{prefix_style}#{prefix}:#{@terminal.reset} "
@@ -170,7 +182,7 @@ module Console
 				prefix_style = @terminal[severity]
 				
 				if @verbose
-					suffix = " #{@terminal[:logger_suffix]}[pid=#{Process.pid}] [#{Time.now}]#{@terminal.reset}"
+					suffix = default_suffix
 				end
 				
 				prefix = "#{prefix_style}#{prefix}:#{@terminal.reset} "
@@ -187,15 +199,7 @@ module Console
 			end
 			
 			def time_offset_prefix
-				offset = Time.now - @start_at
-				minutes = (offset/60).floor
-				seconds = (offset - (minutes*60))
-				
-				if minutes > 0
-					"#{minutes}m#{seconds.floor}s"
-				else
-					"#{seconds.round(2)}s"
-				end.rjust(6)
+				Clock.formatted_duration(Time.now - @start_at).rjust(6)
 			end
 			
 			def build_prefix(name)
